# Canvas

`canvas_ux` ties together a collection of interactive visualizations that let you explore data. It is designed to be extensible and thus can integrate different [components](../widgets). If you are interested in creating you own component, take a look at our [cookiecutter](../widget-cookiecutter/).

## Installation

```bash
pip install canvas_ux
```

## Usage

To learn how to use Canvas, see the [documentation](https://satishlokkoju.github.io/deepview/).

